@@ -1,4 +1,13 @@
-from __future__ import absolute_import
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 
 import unittest
 
@@ -17,7 +26,6 @@ from ..tool_bar_manager import ToolBarManager
 
 
 class FalseActionController(ActionController):
-
     def can_add_to_menu(self, action):
         """ Returns True if the action can be added to a menu/menubar. """
 
@@ -30,23 +38,24 @@ class FalseActionController(ActionController):
 
 
 class TestActionItem(unittest.TestCase, UnittestTools):
-
     def setUp(self):
         # test whether function is called by updating list
         # XXX should really use mock
         self.memo = []
 
         def perform():
-            self.memo.append('called')
+            self.memo.append("called")
 
-        self.action = Action(name='Test', on_perform=perform)
+        self.action = Action(name="Test", on_perform=perform)
 
     def control_factory(self, parent, action):
-        if toolkit_object.toolkit == 'wx':
+        if toolkit_object.toolkit == "wx":
             import wx
+
             control = wx.Control(parent)
-        elif toolkit_object.toolkit == 'qt4':
+        elif toolkit_object.toolkit == "qt4":
             from pyface.qt import QtGui
+
             control = QtGui.QWidget(parent)
         else:
             control = None
@@ -54,25 +63,25 @@ class TestActionItem(unittest.TestCase, UnittestTools):
 
     def test_default_id(self):
         action_item = ActionItem(action=self.action)
-        self.assertEqual(action_item.id, 'Test')
+        self.assertEqual(action_item.id, "Test")
 
     def test_enabled_changed(self):
         # XXX these are only one-way changes, which seems wrong.
         action_item = ActionItem(action=self.action)
-        with self.assertTraitChanges(self.action, 'enabled', count=1):
+        with self.assertTraitChanges(self.action, "enabled", count=1):
             action_item.enabled = False
         self.assertFalse(self.action.enabled)
-        with self.assertTraitChanges(self.action, 'enabled', count=1):
+        with self.assertTraitChanges(self.action, "enabled", count=1):
             action_item.enabled = True
         self.assertTrue(self.action.enabled)
 
     def test_visible_changed(self):
         # XXX these are only one-way changes, which seems wrong.
         action_item = ActionItem(action=self.action)
-        with self.assertTraitChanges(self.action, 'visible', count=1):
+        with self.assertTraitChanges(self.action, "visible", count=1):
             action_item.visible = False
         self.assertFalse(self.action.visible)
-        with self.assertTraitChanges(self.action, 'visible', count=1):
+        with self.assertTraitChanges(self.action, "visible", count=1):
             action_item.visible = True
         self.assertTrue(self.action.visible)
 
@@ -86,7 +95,7 @@ class TestActionItem(unittest.TestCase, UnittestTools):
         window.open()
         action_item = ActionItem(action=self.action)
         menu_bar_manager = MenuBarManager()
-        menu_manager = MenuManager(name='Test')
+        menu_manager = MenuManager(name="Test")
         menu_bar = menu_bar_manager.create_menu_bar(window.control)
         menu = menu_manager.create_menu(menu_bar)
         action_item.add_to_menu(window.control, menu, None)
@@ -97,7 +106,7 @@ class TestActionItem(unittest.TestCase, UnittestTools):
         window.open()
         action_item = ActionItem(action=self.action)
         menu_bar_manager = MenuBarManager()
-        menu_manager = MenuManager(name='Test')
+        menu_manager = MenuManager(name="Test")
         menu_bar = menu_bar_manager.create_menu_bar(window.control)
         menu = menu_manager.create_menu(menu_bar)
         controller = ActionController()
@@ -109,7 +118,7 @@ class TestActionItem(unittest.TestCase, UnittestTools):
         window.open()
         action_item = ActionItem(action=self.action)
         menu_bar_manager = MenuBarManager()
-        menu_manager = MenuManager(name='Test')
+        menu_manager = MenuManager(name="Test")
         menu_bar = menu_bar_manager.create_menu_bar(window.control)
         menu = menu_manager.create_menu(menu_bar)
         controller = FalseActionController()
@@ -120,44 +129,50 @@ class TestActionItem(unittest.TestCase, UnittestTools):
         window = Window()
         window.open()
         action_item = ActionItem(action=self.action)
-        toolbar_manager = ToolBarManager(name='Test')
+        toolbar_manager = ToolBarManager(name="Test")
         image_cache = ImageCache(height=32, width=32)
         menu = toolbar_manager.create_tool_bar(window.control)
-        action_item.add_to_toolbar(window.control, menu, image_cache, None, True)
+        action_item.add_to_toolbar(
+            window.control, menu, image_cache, None, True
+        )
         window.close()
 
     def test_add_to_toolbar_no_label(self):
         window = Window()
         window.open()
         action_item = ActionItem(action=self.action)
-        toolbar_manager = ToolBarManager(name='Test')
+        toolbar_manager = ToolBarManager(name="Test")
         image_cache = ImageCache(height=32, width=32)
         menu = toolbar_manager.create_tool_bar(window.control)
-        action_item.add_to_toolbar(window.control, menu, image_cache, None, False)
+        action_item.add_to_toolbar(
+            window.control, menu, image_cache, None, False
+        )
         window.close()
 
     def test_add_to_toolbar_controller(self):
         window = Window()
         window.open()
         action_item = ActionItem(action=self.action)
-        toolbar_manager = ToolBarManager(name='Test')
+        toolbar_manager = ToolBarManager(name="Test")
         image_cache = ImageCache(height=32, width=32)
         menu = toolbar_manager.create_tool_bar(window.control)
         controller = ActionController()
-        action_item.add_to_toolbar(window.control, menu, image_cache,
-                                   controller, True)
+        action_item.add_to_toolbar(
+            window.control, menu, image_cache, controller, True
+        )
         window.close()
 
     def test_add_to_toolbar_controller_false(self):
         window = Window()
         window.open()
         action_item = ActionItem(action=self.action)
-        toolbar_manager = ToolBarManager(name='Test')
+        toolbar_manager = ToolBarManager(name="Test")
         image_cache = ImageCache(height=32, width=32)
         menu = toolbar_manager.create_tool_bar(window.control)
         controller = FalseActionController()
-        action_item.add_to_toolbar(window.control, menu, image_cache,
-                                   controller, True)
+        action_item.add_to_toolbar(
+            window.control, menu, image_cache, controller, True
+        )
         window.close()
 
     def test_add_to_toolbar_widget(self):
@@ -167,11 +182,13 @@ class TestActionItem(unittest.TestCase, UnittestTools):
         window = Window()
         window.open()
         action_item = ActionItem(action=self.action)
-        toolbar_manager = ToolBarManager(name='Test')
+        toolbar_manager = ToolBarManager(name="Test")
         image_cache = ImageCache(height=32, width=32)
         menu = toolbar_manager.create_tool_bar(window.control)
 
         try:
-            action_item.add_to_toolbar(window.control, menu, image_cache, None, True)
+            action_item.add_to_toolbar(
+                window.control, menu, image_cache, None, True
+            )
         finally:
             window.close()
