@@ -1,22 +1,19 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2005, Enthought, Inc.
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: Enthought, Inc.
-# Description: <Enthought pyface package component>
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 """ The interface for a simple 'About' dialog. """
 
-# Enthought library imports.
-from traits.api import Instance, List, Unicode
 
-# Local imports.
+from traits.api import Instance, List, Str
+
+
 from pyface.i_dialog import IDialog
 from pyface.image_resource import ImageResource
 
@@ -24,13 +21,16 @@ from pyface.image_resource import ImageResource
 class IAboutDialog(IDialog):
     """ The interface for a simple 'About' dialog. """
 
-    #### 'IAboutDialog' interface #############################################
+    # 'IAboutDialog' interface ---------------------------------------------
 
     #: Additional strings to be added to the dialog.
-    additions = List(Unicode)
+    additions = List(Str)
+
+    #: Additional copyright strings to be added above the standard ones.
+    copyrights = List(Str)
 
     #: The image displayed in the dialog.
-    image = Instance(ImageResource, ImageResource('about'))
+    image = Instance(ImageResource, ImageResource("about"))
 
 
 class MAboutDialog(object):
