@@ -1,23 +1,21 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2005, Enthought, Inc.
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 #
 # Author: Enthought, Inc.
 # Description: <Enthought pyface package component>
-#------------------------------------------------------------------------------
 """ The abstract interface for all pyface top-level windows. """
 
 
-# Enthought library imports.
-from traits.api import Event, Tuple, Unicode
+from traits.api import Event, Tuple, Str, Vetoable, VetoableEvent
+
 
-# Local imports.
 from pyface.constant import NO
 from pyface.key_pressed_event import KeyPressedEvent
 from pyface.i_widget import IWidget
@@ -30,54 +28,81 @@ class IWindow(IWidget):
     (ie. its 'control' trait will be None until it is opened).
     """
 
-    #### 'IWindow' interface ##################################################
+    # 'IWindow' interface -----------------------------------------------------
 
     #: The position of the window.
-    position = Tuple
+    position = Tuple()
 
     #: The size of the window.
-    size = Tuple
+    size = Tuple()
 
     #: The window title.
-    title = Unicode
+    title = Str()
 
-    #### Events #####
+    # Window Events ----------------------------------------------------------
+
+    #: The window has been opened.
+    opened = Event()
+
+    #: The window is about to open.
+    opening = VetoableEvent()
 
     #: The window has been activated.
-    activated = Event
+    activated = Event()
 
     #: The window has been closed.
-    closed =  Event
+    closed = Event()
 
     #: The window is about to be closed.
-    closing =  Event
+    closing = VetoableEvent()
 
     #: The window has been deactivated.
-    deactivated = Event
+    deactivated = Event()
 
     #: A key was pressed while the window had focus.
     # FIXME v3: This smells of a hack. What's so special about key presses?
-    # FIXME v3: Unicode
+    # FIXME v3: Str
     key_pressed = Event(KeyPressedEvent)
 
-    #: The window has been opened.
-    opened = Event
-
-    #: The window is about to open.
-    opening = Event
-
-    ###########################################################################
+    # -------------------------------------------------------------------------
     # 'IWindow' interface.
-    ###########################################################################
+    # -------------------------------------------------------------------------
 
     def open(self):
-        """ Opens the window. """
+        """ Opens the window.
 
-    def close(self):
-        """ Closes the window. """
+        This fires the :py:attr:`closing` vetoable event, giving listeners the
+        opportunity to veto the opening of the window.
 
-    def activate(self):
-        """ Activates the window. """
+        If the window is opened, the :py:attr:`opened` event will be fired
+        with the IWindow instance as the event value.
+
+        Returns
+        -------
+        opened : bool
+            Whether or not the window was opened.
+        """
+
+    def close(self, force=False):
+        """ Closes the window.
+
+        This fires the :py:attr:`closing` vetoable event, giving listeners the
+        opportunity to veto the closing of the window.  If :py:obj:`force` is
+        :py:obj:`True` then the window will close no matter what.
+
+        If the window is closed, the closed event will be fired with the window
+        object as the event value.
+
+        Parameters
+        ----------
+        force : bool
+            Whether the window should close despite vetos.
+
+        Returns
+        -------
+        closed : bool
+            Whether or not the window is closed.
+        """
 
     def confirm(self, message, title=None, cancel=False, default=NO):
         """ Convenience method to show a confirmation dialog.
@@ -95,7 +120,8 @@ class IWindow(IWidget):
         """
 
     def information(
-            self, message, title='Information', detail='', informative=''):
+        self, message, title="Information", detail="", informative=""
+    ):
         """ Convenience method to show an information message dialog.
 
         Parameters
@@ -111,7 +137,7 @@ class IWindow(IWidget):
 
         """
 
-    def warning(self, message, title='Warning', detail='', informative=''):
+    def warning(self, message, title="Warning", detail="", informative=""):
         """ Convenience method to show a warning message dialog.
 
         Parameters
@@ -127,7 +153,7 @@ class IWindow(IWidget):
 
         """
 
-    def error(self, message, title='Error', detail='', informative=''):
+    def error(self, message, title="Error", detail="", informative=""):
         """ Convenience method to show an error message dialog.
 
         Parameters
@@ -152,36 +178,62 @@ class MWindow(object):
     Reimplements: _create()
     """
 
-    ###########################################################################
+    # -------------------------------------------------------------------------
     # 'IWindow' interface.
-    ###########################################################################
+    # -------------------------------------------------------------------------
 
     def open(self):
-        """ Opens the window. """
+        """ Opens the window.
 
-        # Trait notification.
-        self.opening = self
+        This fires the :py:attr:`closing` vetoable event, giving listeners the
+        opportunity to veto the opening of the window.
 
-        if self.control is None:
-            self._create()
+        If the window is opened, the :py:attr:`opened` event will be fired
+        with the IWindow instance as the event value.
 
-        self.show(True)
+        Returns
+        -------
+        opened : bool
+            Whether or not the window was opened.
+        """
+        self.opening = event = Vetoable()
+        if not event.veto:
+            # Create the control, if necessary.
+            if self.control is None:
+                self._create()
 
-        # Trait notification.
-        self.opened = self
+            self.show(True)
+            self.opened = self
 
-    def close(self):
-        """ Closes the window. """
+        return self.control is not None and not event.veto
 
+    def close(self, force=False):
+        """ Closes the window.
+
+        This fires the :py:attr:`closing` vetoable event, giving listeners the
+        opportunity to veto the closing of the window.  If :py:obj:`force` is
+        :py:obj:`True` then the window will close no matter what.
+
+        If the window is closed, the closed event will be fired with the window
+        object as the event value.
+
+        Parameters
+        ----------
+        force : bool
+            Whether the window should close despite vetos.
+
+        Returns
+        -------
+        closed : bool
+            Whether or not the window is closed.
+        """
         if self.control is not None:
-            # Trait notification.
-            self.closing = self
+            self.closing = event = Vetoable()
+            if force or not event.veto:
+                self.destroy()
+                self.closed = self
 
-            # Cleanup the toolkit-specific control.
-            self.destroy()
-
-            # Trait notification.
-            self.closed = self
+        return self.control is None
 
     def confirm(self, message, title=None, cancel=False, default=NO):
         """ Convenience method to show a confirmation dialog.
@@ -202,7 +254,8 @@ class MWindow(object):
         return confirm(self.control, message, title, cancel, default)
 
     def information(
-            self, message, title='Information', detail='', informative=''):
+        self, message, title="Information", detail="", informative=""
+    ):
         """ Convenience method to show an information message dialog.
 
         Parameters
@@ -221,7 +274,7 @@ class MWindow(object):
 
         information(self.control, message, title, detail, informative)
 
-    def warning(self, message, title='Warning', detail='', informative=''):
+    def warning(self, message, title="Warning", detail="", informative=""):
         """ Convenience method to show a warning message dialog.
 
         Parameters
@@ -240,7 +293,7 @@ class MWindow(object):
 
         warning(self.control, message, title, detail, informative)
 
-    def error(self, message, title='Error', detail='', informative=''):
+    def error(self, message, title="Error", detail="", informative=""):
         """ Convenience method to show an error message dialog.
 
         Parameters
