@@ -1,18 +1,14 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2005, Enthought, Inc.
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: Enthought, Inc.
-# Description: <Enthought pyface package component>
-#------------------------------------------------------------------------------
-""" A dialog that allows the user to chose a single item from a list. """
+# Thanks for using Enthought open source!
 
+""" A dialog that allows the user to chose a single item from a list. """
 
 
 from .constant import OK
@@ -20,11 +16,11 @@ from .toolkit import toolkit_object
 
 
 # Import the toolkit specific version.
-SingleChoiceDialog = toolkit_object('single_choice_dialog:SingleChoiceDialog')
+SingleChoiceDialog = toolkit_object("single_choice_dialog:SingleChoiceDialog")
 
 
 # Convenience functions.
-def choose_one(parent, message, choices, title='Choose', cancel=True):
+def choose_one(parent, message, choices, title="Choose", cancel=True):
     """ Convenience method to show an information message dialog.
 
     Parameters
@@ -46,8 +42,11 @@ def choose_one(parent, message, choices, title='Choose', cancel=True):
         The selected object, or None if cancelled.
     """
     dialog = SingleChoiceDialog(
-        parent=parent, message=message, choices=choices, title=title,
-        cancel=cancel
+        parent=parent,
+        message=message,
+        choices=choices,
+        title=title,
+        cancel=cancel,
     )
     result = dialog.open()
     if result == OK:
