@@ -1,10 +1,19 @@
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 import unittest
 
 from traits.etsconfig.api import ETSConfig
 
 # Skip tests if Enaml is not installed or we're using the wx backend.
 SKIP_REASON = None
-if ETSConfig.toolkit not in ['', 'qt4']:
+if ETSConfig.toolkit not in ["", "qt4"]:
     SKIP_REASON = "Enaml does not support WX"
 else:
     try:
@@ -20,25 +29,25 @@ if SKIP_REASON is not None:
     class GuiTestAssistant(object):
         pass
 
+
 from pyface.tasks.api import EnamlDockPane, Task
 
 
 class DummyDockPane(EnamlDockPane):
-
     def create_component(self):
-        return Label(text='test label')
+        return Label(text="test label")
 
 
 @unittest.skipIf(SKIP_REASON is not None, SKIP_REASON)
 class TestEnamlDockPane(GuiTestAssistant, unittest.TestCase):
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'TestCase' interface
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def setUp(self):
         GuiTestAssistant.setUp(self)
-        self.dock_pane = DummyDockPane(task=Task(id='dummy_task'))
+        self.dock_pane = DummyDockPane(task=Task(id="dummy_task"))
         with self.event_loop():
             self.dock_pane.create(None)
 
@@ -49,9 +58,9 @@ class TestEnamlDockPane(GuiTestAssistant, unittest.TestCase):
         del self.dock_pane
         GuiTestAssistant.tearDown(self)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Tests
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def test_creation(self):
         self.assertIsInstance(self.dock_pane.component, Label)
