@@ -1,9 +1,19 @@
-from traits.testing.unittest_tools import unittest
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+import unittest
+
 from traits.etsconfig.api import ETSConfig
 
 # Skip tests if Enaml is not installed or we're using the wx backend.
 SKIP_REASON = None
-if ETSConfig.toolkit not in ['', 'qt4']:
+if ETSConfig.toolkit not in ["", "qt4"]:
     SKIP_REASON = "Enaml does not support WX"
 else:
     try:
@@ -26,21 +36,22 @@ from pyface.tasks.api import EnamlEditor
 
 class DummyStrEditor(EnamlEditor):
 
-    obj = Str
+    obj = Str()
 
     def create_component(self):
         return Label(text=self.obj)
 
+
 @unittest.skipIf(SKIP_REASON is not None, SKIP_REASON)
 class TestEnamlEditor(GuiTestAssistant, unittest.TestCase):
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'TestCase' interface
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def setUp(self):
         GuiTestAssistant.setUp(self)
-        self.obj = 'test message'
+        self.obj = "test message"
         self.editor = DummyStrEditor(obj=self.obj)
         with self.event_loop():
             self.editor.create(None)
@@ -52,9 +63,9 @@ class TestEnamlEditor(GuiTestAssistant, unittest.TestCase):
         del self.editor
         GuiTestAssistant.tearDown(self)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Tests
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def test_creation(self):
         self.assertIsInstance(self.editor.component, Label)
