@@ -1,23 +1,17 @@
-#------------------------------------------------------------------------------
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2016, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: Enthought, Inc.
-#
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
-from __future__ import absolute_import
+
+import unittest
 
 from traits.etsconfig.api import ETSConfig
-from traits.testing.unittest_tools import unittest
 
 from ..single_choice_dialog import SingleChoiceDialog
 from ..constant import OK, CANCEL
@@ -25,22 +19,22 @@ from ..gui import GUI
 from ..toolkit import toolkit_object
 from ..window import Window
 
-GuiTestAssistant = toolkit_object('util.gui_test_assistant:GuiTestAssistant')
-no_gui_test_assistant = (GuiTestAssistant.__name__ == 'Unimplemented')
+GuiTestAssistant = toolkit_object("util.gui_test_assistant:GuiTestAssistant")
+no_gui_test_assistant = GuiTestAssistant.__name__ == "Unimplemented"
 
 ModalDialogTester = toolkit_object(
-    'util.modal_dialog_tester:ModalDialogTester'
+    "util.modal_dialog_tester:ModalDialogTester"
 )  # noqa: E501
-no_modal_dialog_tester = (ModalDialogTester.__name__ == 'Unimplemented')
+no_modal_dialog_tester = ModalDialogTester.__name__ == "Unimplemented"
 
-USING_QT = ETSConfig.toolkit not in ['', 'wx']
+USING_QT = ETSConfig.toolkit not in ["", "wx"]
 
 
-@unittest.skipIf(no_gui_test_assistant, 'No GuiTestAssistant')
+@unittest.skipIf(no_gui_test_assistant, "No GuiTestAssistant")
 class TestSingleChoiceDialog(unittest.TestCase, GuiTestAssistant):
     def setUp(self):
         GuiTestAssistant.setUp(self)
-        self.dialog = SingleChoiceDialog(choices=['red', 'blue', 'green'])
+        self.dialog = SingleChoiceDialog(choices=["red", "blue", "green"])
 
     def tearDown(self):
         if self.dialog.control is not None:
@@ -93,13 +87,13 @@ class TestSingleChoiceDialog(unittest.TestCase, GuiTestAssistant):
     def test_choice_strings(self):
         # test that choice strings work using simple strings
         self.assertEqual(
-            self.dialog._choice_strings(), ['red', 'blue', 'green']
+            self.dialog._choice_strings(), ["red", "blue", "green"]
         )
 
     def test_choice_strings_convert(self):
         # test that choice strings work using simple strings
         self.dialog.choices = [1, 2, 3]
-        self.assertEqual(self.dialog._choice_strings(), ['1', '2', '3'])
+        self.assertEqual(self.dialog._choice_strings(), ["1", "2", "3"])
 
     def test_choice_strings_name_attribute(self):
         # test that choice strings work using attribute name of objects
@@ -107,10 +101,10 @@ class TestSingleChoiceDialog(unittest.TestCase, GuiTestAssistant):
             def __init__(self, description):
                 self.description = description
 
-        self.dialog.choices = [Item(name) for name in ['red', 'blue', 'green']]
-        self.dialog.name_attribute = 'description'
+        self.dialog.choices = [Item(name) for name in ["red", "blue", "green"]]
+        self.dialog.name_attribute = "description"
         self.assertEqual(
-            self.dialog._choice_strings(), ['red', 'blue', 'green']
+            self.dialog._choice_strings(), ["red", "blue", "green"]
         )
 
     def test_choice_strings_name_attribute_convert(self):
@@ -120,8 +114,8 @@ class TestSingleChoiceDialog(unittest.TestCase, GuiTestAssistant):
                 self.description = description
 
         self.dialog.choices = [Item(name) for name in [1, 2, 3]]
-        self.dialog.name_attribute = 'description'
-        self.assertEqual(self.dialog._choice_strings(), ['1', '2', '3'])
+        self.dialog.name_attribute = "description"
+        self.assertEqual(self.dialog._choice_strings(), ["1", "2", "3"])
 
     def test_choice_strings_empty(self):
         # test that choice strings work using simple strings
@@ -131,20 +125,20 @@ class TestSingleChoiceDialog(unittest.TestCase, GuiTestAssistant):
 
     def test_choice_strings_duplicated(self):
         # test that choice strings work using simple strings
-        self.dialog.choices = ['red', 'green', 'blue', 'green']
+        self.dialog.choices = ["red", "green", "blue", "green"]
         with self.assertRaises(ValueError):
             self.dialog._choice_strings()
 
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     def test_accept(self):
         # test that accept works as expected
         tester = ModalDialogTester(self.dialog.open)
         tester.open_and_run(when_opened=lambda x: x.close(accept=True))
         self.assertEqual(tester.result, OK)
         self.assertEqual(self.dialog.return_code, OK)
-        self.assertEqual(self.dialog.choice, 'red')
+        self.assertEqual(self.dialog.choice, "red")
 
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     def test_reject(self):
         # test that accept works as expected
         tester = ModalDialogTester(self.dialog.open)
@@ -154,7 +148,7 @@ class TestSingleChoiceDialog(unittest.TestCase, GuiTestAssistant):
         self.assertEqual(self.dialog.return_code, CANCEL)
         self.assertIsNone(self.dialog.choice)
 
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     def test_close(self):
         # test that closing works as expected
         tester = ModalDialogTester(self.dialog.open)
@@ -166,7 +160,7 @@ class TestSingleChoiceDialog(unittest.TestCase, GuiTestAssistant):
         self.assertEqual(self.dialog.return_code, CANCEL)
         self.assertIsNone(self.dialog.choice)
 
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     def test_parent(self):
         # test that lifecycle works with a parent
         parent = Window()
@@ -180,7 +174,7 @@ class TestSingleChoiceDialog(unittest.TestCase, GuiTestAssistant):
         self.assertEqual(tester.result, OK)
         self.assertEqual(self.dialog.return_code, OK)
 
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     def test_change_choice_accept(self):
         # test that if we change choice it's reflected in result
         def select_green_and_ok(tester):
@@ -193,9 +187,9 @@ class TestSingleChoiceDialog(unittest.TestCase, GuiTestAssistant):
 
         self.assertEqual(tester.result, OK)
         self.assertEqual(self.dialog.return_code, OK)
-        self.assertEqual(self.dialog.choice, 'green')
+        self.assertEqual(self.dialog.choice, "green")
 
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     def test_change_choice_with_reject(self):
         # test that lifecycle works with a parent
         def select_green_and_cancel(tester):
@@ -210,7 +204,7 @@ class TestSingleChoiceDialog(unittest.TestCase, GuiTestAssistant):
         self.assertEqual(self.dialog.return_code, CANCEL)
         self.assertIsNone(self.dialog.choice)
 
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     def test_change_choice_with_close(self):
         # test that lifecycle works with a parent
         def select_green_and_close(tester):
