@@ -1,37 +1,30 @@
-# Copyright (c) 2007, Riverbank Computing Limited
-# Copyright (c) 2019, Enthought, Inc.
+# (C) Copyright 2007 Riverbank Computing Limited
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
-# This software is provided without warranty under the terms of the BSD license.
-# However, when used with the GPL version of PyQt the additional terms described
-# in the PyQt GPL exception also apply.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-# Author: Riverbank Computing Limited
-# Description: <Enthought pyface package component>
+# Thanks for using Enthought open source!
 
 """ The PyQt specific implementations the action manager internal classes. """
 
 
-# Standard library imports.
-import six
-if six.PY2:
-    from inspect import getargspec
-else:
-    # avoid deprecation warning
-    from inspect import getfullargspec as getargspec
+from inspect import getfullargspec
+
 
-# Major package imports.
 from pyface.qt import QtGui, QtCore
 
-# Enthought library imports.
+
 from traits.api import Any, Bool, HasTraits
 
-# Local imports.
+
 from pyface.action.action_event import ActionEvent
 
 
 class PyfaceWidgetAction(QtGui.QWidgetAction):
-
     def __init__(self, parent, action):
         super(PyfaceWidgetAction, self).__init__(parent)
         self.action = action
@@ -45,13 +38,13 @@ class PyfaceWidgetAction(QtGui.QWidgetAction):
 class _MenuItem(HasTraits):
     """ A menu item representation of an action item. """
 
-    #### '_MenuItem' interface ################################################
+    # '_MenuItem' interface ------------------------------------------------
 
     # Is the item checked?
     checked = Bool(False)
 
     # A controller object we delegate taking actions through (if any).
-    controller = Any
+    controller = Any()
 
     # Is the item enabled?
     enabled = Bool(True)
@@ -61,7 +54,7 @@ class _MenuItem(HasTraits):
 
     # The radio group we are part of (None if the menu item is not part of such
     # a group).
-    group = Any
+    group = Any()
 
     # The toolkit control.
     control = Any()
@@ -69,9 +62,9 @@ class _MenuItem(HasTraits):
     # The toolkit control id.
     control_id = None
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'object' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def __init__(self, parent, menu, item, controller):
         """ Creates a new menu item for an action item. """
@@ -82,15 +75,20 @@ class _MenuItem(HasTraits):
         # FIXME v3: This is a wx'ism and should be hidden in the toolkit code.
         self.control_id = None
 
-        if action.style == 'widget':
+        if action.style == "widget":
             self.control = PyfaceWidgetAction(parent, action)
             menu.addAction(self.control)
         elif action.image is None:
-            self.control = menu.addAction(action.name, self._qt4_on_triggered,
-                    action.accelerator)
+            self.control = menu.addAction(
+                action.name, self._qt4_on_triggered, action.accelerator
+            )
         else:
-            self.control = menu.addAction(action.image.create_icon(),
-                    action.name, self._qt4_on_triggered, action.accelerator)
+            self.control = menu.addAction(
+                action.image.create_icon(),
+                action.name,
+                self._qt4_on_triggered,
+                action.accelerator,
+            )
         menu.menu_items.append(self)
 
         self.control.setToolTip(action.tooltip)
@@ -98,16 +96,16 @@ class _MenuItem(HasTraits):
         self.control.setEnabled(action.enabled)
         self.control.setVisible(action.visible)
 
-        if getattr(action, 'menu_role', False):
+        if getattr(action, "menu_role", False):
             if action.menu_role == "About":
                 self.control.setMenuRole(QtGui.QAction.AboutRole)
             elif action.menu_role == "Preferences":
                 self.control.setMenuRole(QtGui.QAction.PreferencesRole)
 
-        if action.style == 'toggle':
+        if action.style == "toggle":
             self.control.setCheckable(True)
             self.control.setChecked(action.checked)
-        elif action.style == 'radio':
+        elif action.style == "radio":
             # Create an action group if it hasn't already been done.
             try:
                 ag = item.parent._qt4_ag
@@ -121,12 +119,15 @@ class _MenuItem(HasTraits):
 
         # Listen for trait changes on the action (so that we can update its
         # enabled/disabled/checked state etc).
-        action.on_trait_change(self._on_action_enabled_changed, 'enabled')
-        action.on_trait_change(self._on_action_visible_changed, 'visible')
-        action.on_trait_change(self._on_action_checked_changed, 'checked')
-        action.on_trait_change(self._on_action_name_changed, 'name')
-        action.on_trait_change(self._on_action_accelerator_changed,
-                               'accelerator')
+        action.on_trait_change(self._on_action_enabled_changed, "enabled")
+        action.on_trait_change(self._on_action_visible_changed, "visible")
+        action.on_trait_change(self._on_action_checked_changed, "checked")
+        action.on_trait_change(self._on_action_name_changed, "name")
+        action.on_trait_change(
+            self._on_action_accelerator_changed, "accelerator"
+        )
+        action.on_trait_change(self._on_action_image_changed, "image")
+        action.on_trait_change(self._on_action_tooltip_changed, "tooltip")
 
         # Detect if the control is destroyed.
         self.control.destroyed.connect(self._qt4_on_destroyed)
@@ -137,20 +138,31 @@ class _MenuItem(HasTraits):
 
     def dispose(self):
         action = self.item.action
-        action.on_trait_change(self._on_action_enabled_changed, 'enabled',
-            remove=True)
-        action.on_trait_change(self._on_action_visible_changed, 'visible',
-            remove=True)
-        action.on_trait_change(self._on_action_checked_changed, 'checked',
-            remove=True)
-        action.on_trait_change(self._on_action_name_changed, 'name',
-            remove=True)
-        action.on_trait_change(self._on_action_accelerator_changed,
-            'accelerator', remove=True)
+        action.on_trait_change(
+            self._on_action_enabled_changed, "enabled", remove=True
+        )
+        action.on_trait_change(
+            self._on_action_visible_changed, "visible", remove=True
+        )
+        action.on_trait_change(
+            self._on_action_checked_changed, "checked", remove=True
+        )
+        action.on_trait_change(
+            self._on_action_name_changed, "name", remove=True
+        )
+        action.on_trait_change(
+            self._on_action_accelerator_changed, "accelerator", remove=True
+        )
+        action.on_trait_change(
+            self._on_action_image_changed, "image", remove=True
+        )
+        action.on_trait_change(
+            self._on_action_tooltip_changed, "tooltip", remove=True
+        )
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Private interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _qt4_on_destroyed(self, control=None):
         """ Delete the reference to the control to avoid attempting to talk to
@@ -164,7 +176,7 @@ class _MenuItem(HasTraits):
         action = self.item.action
         action_event = ActionEvent()
 
-        is_checkable = action.style in ['radio', 'toggle']
+        is_checkable = action.style in ["radio", "toggle"]
 
         # Perform the action!
         if self.controller is not None:
@@ -175,7 +187,7 @@ class _MenuItem(HasTraits):
             # contains information about the time the event occurred etc), so
             # we only pass it if the perform method requires it. This is also
             # useful as Traits UI controllers *never* require the event.
-            argspec = getargspec(self.controller.perform)
+            argspec = getfullargspec(self.controller.perform)
 
             # If the only arguments are 'self' and 'action' then don't pass
             # the event!
@@ -192,16 +204,16 @@ class _MenuItem(HasTraits):
             # Most of the time, action's do no care about the event (it
             # contains information about the time the event occurred etc), so
             # we only pass it if the perform method requires it.
-            argspec = getargspec(action.perform)
+            argspec = getfullargspec(action.perform)
 
             # If the only argument is 'self' then don't pass the event!
-            if len(argspec.argspecargs) == 1:
+            if len(argspec.args) == 1:
                 action.perform()
 
             else:
                 action.perform(action_event)
 
-    #### Trait event handlers #################################################
+    # Trait event handlers -------------------------------------------------
 
     def _enabled_changed(self):
         """ Called when our 'enabled' trait is changed. """
@@ -243,17 +255,27 @@ class _MenuItem(HasTraits):
         if self.control is not None:
             self.control.setShortcut(action.accelerator)
 
+    def _on_action_image_changed(self, action, trait_name, old, new):
+        """ Called when the accelerator trait is changed on an action. """
+        if self.control is not None:
+            self.control.setIcon(action.image.create_icon())
+
+    def _on_action_tooltip_changed(self, action, trait_name, old, new):
+        """ Called when the accelerator trait is changed on an action. """
+        if self.control is not None:
+            self.control.setToolTip(action.tooltip)
+
 
 class _Tool(HasTraits):
     """ A tool bar tool representation of an action item. """
 
-    #### '_Tool' interface ####################################################
+    # '_Tool' interface ----------------------------------------------------
 
     # Is the item checked?
     checked = Bool(False)
 
     # A controller object we delegate taking actions through (if any).
-    controller = Any
+    controller = Any()
 
     # Is the item enabled?
     enabled = Bool(True)
@@ -263,7 +285,7 @@ class _Tool(HasTraits):
 
     # The radio group we are part of (None if the tool is not part of such a
     # group).
-    group = Any
+    group = Any()
 
     # The toolkit control.
     control = Any()
@@ -271,19 +293,20 @@ class _Tool(HasTraits):
     # The toolkit control id.
     control_id = None
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'object' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
-    def __init__(self, parent, tool_bar, image_cache, item, controller,
-                 show_labels):
+    def __init__(
+        self, parent, tool_bar, image_cache, item, controller, show_labels
+    ):
         """ Creates a new tool bar tool for an action item. """
 
         self.item = item
         self.tool_bar = tool_bar
         action = item.action
 
-        if action.style == 'widget':
+        if action.style == "widget":
             widget = action.create_control(tool_bar)
             self.control = tool_bar.addWidget(widget)
         elif action.image is None:
@@ -300,10 +323,10 @@ class _Tool(HasTraits):
         self.control.setEnabled(action.enabled)
         self.control.setVisible(action.visible)
 
-        if action.style == 'toggle':
+        if action.style == "toggle":
             self.control.setCheckable(True)
             self.control.setChecked(action.checked)
-        elif action.style == 'radio':
+        elif action.style == "radio":
             # Create an action group if it hasn't already been done.
             try:
                 ag = item.parent._qt4_ag
@@ -322,12 +345,15 @@ class _Tool(HasTraits):
 
         # Listen for trait changes on the action (so that we can update its
         # enabled/disabled/checked state etc).
-        action.on_trait_change(self._on_action_enabled_changed, 'enabled')
-        action.on_trait_change(self._on_action_visible_changed, 'visible')
-        action.on_trait_change(self._on_action_checked_changed, 'checked')
-        action.on_trait_change(self._on_action_name_changed, 'name')
-        action.on_trait_change(self._on_action_accelerator_changed,
-                               'accelerator')
+        action.on_trait_change(self._on_action_enabled_changed, "enabled")
+        action.on_trait_change(self._on_action_visible_changed, "visible")
+        action.on_trait_change(self._on_action_checked_changed, "checked")
+        action.on_trait_change(self._on_action_name_changed, "name")
+        action.on_trait_change(
+            self._on_action_accelerator_changed, "accelerator"
+        )
+        action.on_trait_change(self._on_action_image_changed, "image")
+        action.on_trait_change(self._on_action_tooltip_changed, "tooltip")
 
         # Detect if the control is destroyed.
         self.control.destroyed.connect(self._qt4_on_destroyed)
@@ -336,9 +362,9 @@ class _Tool(HasTraits):
             self.controller = controller
             controller.add_to_toolbar(self)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Private interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _qt4_on_destroyed(self, control=None):
         """ Delete the reference to the control to avoid attempting to talk to
@@ -360,7 +386,7 @@ class _Tool(HasTraits):
             # contains information about the time the event occurred etc), so
             # we only pass it if the perform method requires it. This is also
             # useful as Traits UI controllers *never* require the event.
-            argspec = getargspec(self.controller.perform)
+            argspec = getfullargspec(self.controller.perform)
 
             # If the only arguments are 'self' and 'action' then don't pass
             # the event!
@@ -376,7 +402,7 @@ class _Tool(HasTraits):
             # Most of the time, action's do no care about the event (it
             # contains information about the time the event occurred etc), so
             # we only pass it if the perform method requires it.
-            argspec = getargspec(action.perform)
+            argspec = getfullargspec(action.perform)
 
             # If the only argument is 'self' then don't pass the event!
             if len(argspec.args) == 1:
@@ -385,7 +411,7 @@ class _Tool(HasTraits):
             else:
                 action.perform(action_event)
 
-    #### Trait event handlers #################################################
+    # Trait event handlers -------------------------------------------------
 
     def _enabled_changed(self):
         """ Called when our 'enabled' trait is changed. """
@@ -427,19 +453,32 @@ class _Tool(HasTraits):
         if self.control is not None:
             self.control.setShortcut(action.accelerator)
 
+    def _on_action_image_changed(self, action, trait_name, old, new):
+        """ Called when the accelerator trait is changed on an action. """
+        if self.control is not None:
+            size = self.tool_bar.iconSize()
+            self.control.setIcon(
+                action.image.create_icon((size.width(), size.height()))
+            )
+
+    def _on_action_tooltip_changed(self, action, trait_name, old, new):
+        """ Called when the accelerator trait is changed on an action. """
+        if self.control is not None:
+            self.control.setToolTip(action.tooltip)
+
 
 class _PaletteTool(HasTraits):
     """ A tool palette representation of an action item. """
 
-    #### '_PaletteTool' interface #############################################
+    # '_PaletteTool' interface ---------------------------------------------
 
     # The radio group we are part of (None if the tool is not part of such a
     # group).
-    group = Any
+    group = Any()
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'object' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def __init__(self, tool_palette, image_cache, item, show_labels):
         """ Creates a new tool palette tool for an action item. """
@@ -452,56 +491,57 @@ class _PaletteTool(HasTraits):
 
         if action.style == "widget":
             raise NotImplementedError(
-                "Qt does not support widgets in palettes")
+                "Qt does not support widgets in palettes"
+            )
 
         # Tool palette tools never have '...' at the end.
-        if label.endswith('...'):
+        if label.endswith("..."):
             label = label[:-3]
 
         # And they never contain shortcuts.
-        label = label.replace('&', '')
+        label = label.replace("&", "")
 
         image = action.image.create_image()
         path = action.image.absolute_path
         bmp = image_cache.get_bitmap(path)
 
-        kind    = action.style
+        kind = action.style
         tooltip = action.tooltip
         longtip = action.description
 
         if not show_labels:
-            label = ''
+            label = ""
 
         # Add the tool to the tool palette.
-        self.tool_id = tool_palette.add_tool(label, bmp, kind, tooltip,longtip)
+        self.tool_id = tool_palette.add_tool(
+            label, bmp, kind, tooltip, longtip
+        )
         tool_palette.toggle_tool(self.tool_id, action.checked)
         tool_palette.enable_tool(self.tool_id, action.enabled)
         tool_palette.on_tool_event(self.tool_id, self._on_tool)
 
         # Listen to the trait changes on the action (so that we can update its
         # enabled/disabled/checked state etc).
-        action.on_trait_change(self._on_action_enabled_changed, 'enabled')
-        action.on_trait_change(self._on_action_checked_changed, 'checked')
+        action.on_trait_change(self._on_action_enabled_changed, "enabled")
+        action.on_trait_change(self._on_action_checked_changed, "checked")
 
         return
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Private interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
-    #### Trait event handlers #################################################
+    # Trait event handlers -------------------------------------------------
 
     def _on_action_enabled_changed(self, action, trait_name, old, new):
         """ Called when the enabled trait is changed on an action. """
 
         self.tool_palette.enable_tool(self.tool_id, action.enabled)
 
-        return
-
     def _on_action_checked_changed(self, action, trait_name, old, new):
         """ Called when the checked trait is changed on an action. """
 
-        if action.style == 'radio':
+        if action.style == "radio":
             # If we're turning this one on, then we need to turn all the others
             # off.  But if we're turning this one off, don't worry about the
             # others.
@@ -515,7 +555,7 @@ class _PaletteTool(HasTraits):
 
         return
 
-    #### Tool palette event handlers ##########################################
+    # Tool palette event handlers -----------------------------------------#
 
     def _on_tool(self, event):
         """ Called when the tool palette button is clicked. """
@@ -523,7 +563,7 @@ class _PaletteTool(HasTraits):
         action = self.item.action
         action_event = ActionEvent()
 
-        is_checkable = (action.style == 'radio' or action.style == 'check')
+        is_checkable = action.style == "radio" or action.style == "check"
 
         # Perform the action!
         action.checked = self.tool_palette.get_tool_state(self.tool_id) == 1
