@@ -1,23 +1,26 @@
-# Copyright (c) 2013-2017 by Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 
 import contextlib
 import gc
 import threading
 
-import mock
+
+import unittest.mock as mock
 
 from pyface.qt.QtGui import QApplication
 from pyface.ui.qt4.gui import GUI
 from traits.testing.unittest_tools import UnittestTools
-from traits.testing.unittest_tools import _TraitsChangeCollector as \
-    TraitsChangeCollector
+from traits.testing.unittest_tools import (
+    _TraitsChangeCollector as TraitsChangeCollector,
+)
 
 from .testing import find_qt_widget, print_qt_widget_tree
 from .event_loop_helper import EventLoopHelper, ConditionTimeoutError
@@ -25,7 +28,7 @@ from .event_loop_helper import EventLoopHelper, ConditionTimeoutError
 
 class GuiTestAssistant(UnittestTools):
 
-    #### 'TestCase' protocol ##################################################
+    # 'TestCase' protocol -------------------------------------------------#
 
     def setUp(self):
         qt_app = QApplication.instance()
@@ -34,19 +37,25 @@ class GuiTestAssistant(UnittestTools):
         self.qt_app = qt_app
         self.gui = GUI()
         self.event_loop_helper = EventLoopHelper(
-            qt_app=self.qt_app,
-            gui=self.gui
+            qt_app=self.qt_app, gui=self.gui
         )
-        self.traitsui_raise_patch = mock.patch(
-            'traitsui.qt4.ui_base._StickyDialog.raise_')
-        self.traitsui_raise_patch.start()
+        try:
+            import traitsui.api
+        except ImportError:
+            self.traitsui_raise_patch = None
+        else:
+            self.traitsui_raise_patch = mock.patch(
+                "traitsui.qt4.ui_base._StickyDialog.raise_"
+            )
+            self.traitsui_raise_patch.start()
 
         def new_activate(self):
             self.control.activateWindow()
 
         self.pyface_raise_patch = mock.patch(
-            'pyface.ui.qt4.window.Window.activate',
-            new_callable=lambda: new_activate)
+            "pyface.ui.qt4.window.Window.activate",
+            new_callable=lambda: new_activate,
+        )
         self.pyface_raise_patch.start()
 
     def tearDown(self):
@@ -68,7 +77,8 @@ class GuiTestAssistant(UnittestTools):
 
         self.qt_app.flush()
         self.pyface_raise_patch.stop()
-        self.traitsui_raise_patch.stop()
+        if self.traitsui_raise_patch is not None:
+            self.traitsui_raise_patch.stop()
 
         del self.pyface_raise_patch
         del self.traitsui_raise_patch
@@ -76,7 +86,7 @@ class GuiTestAssistant(UnittestTools):
         del self.gui
         del self.qt_app
 
-    #### 'GuiTestAssistant' protocol ##########################################
+    # 'GuiTestAssistant' protocol -----------------------------------------#
 
     @contextlib.contextmanager
     def event_loop(self, repeat=1):
@@ -111,8 +121,9 @@ class GuiTestAssistant(UnittestTools):
             with self.event_loop_helper.delete_widget(widget, timeout=timeout):
                 yield
         except ConditionTimeoutError:
-            self.fail('Could not destroy widget before timeout: {!r}'.format(
-                widget))
+            self.fail(
+                "Could not destroy widget before timeout: {!r}".format(widget)
+            )
 
     @contextlib.contextmanager
     def event_loop_until_condition(self, condition, timeout=10.0):
@@ -134,13 +145,44 @@ class GuiTestAssistant(UnittestTools):
         try:
             yield
             self.event_loop_helper.event_loop_until_condition(
-                condition, timeout=timeout)
+                condition, timeout=timeout
+            )
         except ConditionTimeoutError:
-            self.fail('Timed out waiting for condition')
+            self.fail("Timed out waiting for condition")
+
+    def assertEventuallyTrueInGui(self, condition, timeout=10.0):
+        """
+        Assert that the given condition becomes true if we run the GUI
+        event loop for long enough.
+
+        This assertion runs the real Qt event loop, polling the condition
+        and returning as soon as the condition becomes true. If the condition
+        does not become true within the given timeout, the assertion fails.
+
+        Parameters
+        ----------
+        condition : callable() -> bool
+            Callable accepting no arguments and returning a bool.
+        timeout : float
+            Maximum length of time to wait for the condition to become
+            true, in seconds.
+
+        Raises
+        ------
+        self.failureException
+            If the condition does not become true within the given timeout.
+        """
+        try:
+            self.event_loop_helper.event_loop_until_condition(
+                condition, timeout=timeout
+            )
+        except ConditionTimeoutError:
+            self.fail("Timed out waiting for condition to become true.")
 
     @contextlib.contextmanager
-    def assertTraitChangesInEventLoop(self, obj, trait, condition, count=1,
-                                      timeout=10.0):
+    def assertTraitChangesInEventLoop(
+        self, obj, trait, condition, count=1, timeout=10.0
+    ):
         """Runs the real Qt event loop, collecting trait change events until
         the provided condition evaluates to True.
 
@@ -161,21 +203,25 @@ class GuiTestAssistant(UnittestTools):
             change does not occur.
         """
         condition_ = lambda: condition(obj)
-        collector = TraitsChangeCollector(obj=obj, trait=trait)
+        collector = TraitsChangeCollector(obj=obj, trait_name=trait)
 
         collector.start_collecting()
         try:
             try:
                 yield collector
                 self.event_loop_helper.event_loop_until_condition(
-                    condition_, timeout=timeout)
+                    condition_, timeout=timeout
+                )
             except ConditionTimeoutError:
                 actual_event_count = collector.event_count
-                msg = ("Expected {} event on {} to be fired at least {} "
-                       "times, but the event was only fired {} times "
-                       "before timeout ({} seconds).")
+                msg = (
+                    "Expected {} event on {} to be fired at least {} "
+                    "times, but the event was only fired {} times "
+                    "before timeout ({} seconds)."
+                )
                 msg = msg.format(
-                    trait, obj, count, actual_event_count, timeout)
+                    trait, obj, count, actual_event_count, timeout
+                )
                 self.fail(msg)
         finally:
             collector.stop_collecting()
@@ -195,7 +241,7 @@ class GuiTestAssistant(UnittestTools):
             Number of seconds to run the event loop in the case that the trait
             change does not occur. Default value is 10.0.
         """
-        timeout = kw.pop('timeout', 10.0)
+        timeout = kw.pop("timeout", 10.0)
         condition = threading.Event()
 
         traits = set(traits)
@@ -213,6 +259,7 @@ class GuiTestAssistant(UnittestTools):
         def make_handler(trait):
             def handler():
                 set_event(trait)
+
             return handler
 
         handlers = {trait: make_handler(trait) for trait in traits}
@@ -221,7 +268,8 @@ class GuiTestAssistant(UnittestTools):
             traits_object.on_trait_change(handler, trait)
         try:
             with self.event_loop_until_condition(
-                    condition=condition.is_set, timeout=timeout):
+                condition=condition.is_set, timeout=timeout
+            ):
                 yield
         finally:
             for trait, handler in handlers.items():
@@ -246,7 +294,8 @@ class GuiTestAssistant(UnittestTools):
         """
         yield
         self.event_loop_helper.event_loop_with_timeout(
-            repeat=repeat, timeout=timeout)
+            repeat=repeat, timeout=timeout
+        )
 
     def find_qt_widget(self, start, type_, test=None):
         """Recursively walks the Qt widget tree from Qt widget `start` until it
