@@ -1,24 +1,29 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2007, Riverbank Computing Limited
+# (C) Copyright 2007 Riverbank Computing Limited
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
-# This software is provided without warranty under the terms of the BSD license.
-# However, when used with the GPL version of PyQt the additional terms described in the PyQt GPL exception also apply
-
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-# Author: Riverbank Computing Limited
-# Description: <Enthought pyface package component>
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 
-# Major package imports.
 from pyface.qt import QtCore, QtGui
 
-# Enthought library imports.
-from traits.api import Enum, Event, Property, provides, Unicode
-from traits.api import Tuple
 
-# Local imports.
+from traits.api import (
+    Enum,
+    Event,
+    Property,
+    Tuple,
+    Str,
+    VetoableEvent,
+    provides,
+)
+
+
 from pyface.i_window import IWindow, MWindow
 from pyface.key_pressed_event import KeyPressedEvent
 from .gui import GUI
@@ -31,52 +36,57 @@ class Window(MWindow, Widget):
     interface for the API documentation.
     """
 
-
-    #### 'IWindow' interface ##################################################
+    # 'IWindow' interface -----------------------------------------------------
 
     position = Property(Tuple)
 
     size = Property(Tuple)
 
-    size_state = Enum('normal', 'maximized')
+    size_state = Enum("normal", "maximized")
 
-    title = Unicode
+    title = Str()
 
-    #### Events #####
+    # Window Events ----------------------------------------------------------
 
-    activated = Event
+    #: The window has been opened.
+    opened = Event()
 
-    closed =  Event
+    #: The window is about to open.
+    opening = VetoableEvent()
 
-    closing =  Event
+    #: The window has been activated.
+    activated = Event()
 
-    deactivated = Event
+    #: The window has been closed.
+    closed = Event()
 
-    key_pressed = Event(KeyPressedEvent)
+    #: The window is about to be closed.
+    closing = VetoableEvent()
 
-    opened = Event
+    #: The window has been deactivated.
+    deactivated = Event()
 
-    opening = Event
+    # Private interface ------------------------------------------------------
 
-    #### Private interface ####################################################
-
-    # Shadow trait for position.
+    #: Shadow trait for position.
     _position = Tuple((-1, -1))
 
-    # Shadow trait for size.
+    #: Shadow trait for size.
     _size = Tuple((-1, -1))
 
-    ###########################################################################
+    # -------------------------------------------------------------------------
     # 'IWindow' interface.
-    ###########################################################################
+    # -------------------------------------------------------------------------
 
     def activate(self):
         self.control.activateWindow()
         self.control.raise_()
+        # explicitly fire activated trait as signal doesn't create Qt event
+        self.activated = self
 
-    ###########################################################################
+    # -------------------------------------------------------------------------
     # Protected 'IWindow' interface.
-    ###########################################################################
+    # -------------------------------------------------------------------------
 
     def _create_control(self, parent):
         """ Create a default QMainWindow. """
@@ -86,7 +96,7 @@ class Window(MWindow, Widget):
             control.resize(*self.size)
         if self.position != (-1, -1):
             control.move(*self.position)
-        if self.size_state != 'normal':
+        if self.size_state != "normal":
             self._size_state_changed(self.size_state)
         control.setWindowTitle(self.title)
         control.setEnabled(self.enabled)
@@ -96,9 +106,9 @@ class Window(MWindow, Widget):
 
         return control
 
-    ###########################################################################
+    # -------------------------------------------------------------------------
     # 'IWidget' interface.
-    ###########################################################################
+    # -------------------------------------------------------------------------
 
     def destroy(self):
         self._remove_event_listeners()
@@ -118,9 +128,9 @@ class Window(MWindow, Widget):
             super(Window, self).destroy()
             control.close()
 
-    ###########################################################################
+    # -------------------------------------------------------------------------
     # Private interface.
-    ###########################################################################
+    # -------------------------------------------------------------------------
 
     def _get_position(self):
         """ Property getter for position. """
@@ -136,7 +146,7 @@ class Window(MWindow, Widget):
         old = self._position
         self._position = position
 
-        self.trait_property_changed('position', old, position)
+        self.trait_property_changed("position", old, position)
 
     def _get_size(self):
         """ Property getter for size. """
@@ -152,17 +162,21 @@ class Window(MWindow, Widget):
         old = self._size
         self._size = size
 
-        self.trait_property_changed('size', old, size)
+        self.trait_property_changed("size", old, size)
 
     def _size_state_changed(self, state):
         control = self.control
         if control is None:
-            return # Nothing to do here
+            return  # Nothing to do here
 
-        if state == 'maximized':
-            control.setWindowState(control.windowState() | QtCore.Qt.WindowMaximized)
-        elif state == 'normal':
-            control.setWindowState(control.windowState() & ~QtCore.Qt.WindowMaximized)
+        if state == "maximized":
+            control.setWindowState(
+                control.windowState() | QtCore.Qt.WindowMaximized
+            )
+        elif state == "normal":
+            control.setWindowState(
+                control.windowState() & ~QtCore.Qt.WindowMaximized
+            )
 
     def _title_changed(self, title):
         """ Static trait change handler. """
@@ -227,7 +241,7 @@ class WindowEventFilter(QtCore.QObject):
             window._position = (pos.x(), pos.y())
 
         elif typ == QtCore.QEvent.KeyPress:
-            # Pyface doesn't seem to be Unicode aware.  Only keep the key code
+            # Pyface doesn't seem to be Str aware.  Only keep the key code
             # if it corresponds to a single Latin1 character.
             kstr = e.text()
             try:
@@ -237,21 +251,26 @@ class WindowEventFilter(QtCore.QObject):
 
             mods = e.modifiers()
             window.key_pressed = KeyPressedEvent(
-                alt_down     = ((mods & QtCore.Qt.AltModifier) ==
-                                QtCore.Qt.AltModifier),
-                control_down = ((mods & QtCore.Qt.ControlModifier) ==
-                                QtCore.Qt.ControlModifier),
-                shift_down   = ((mods & QtCore.Qt.ShiftModifier) ==
-                                QtCore.Qt.ShiftModifier),
-                key_code     = kcode,
-                event        = e)
+                alt_down=(
+                    (mods & QtCore.Qt.AltModifier) == QtCore.Qt.AltModifier
+                ),
+                control_down=(
+                    (mods & QtCore.Qt.ControlModifier)
+                    == QtCore.Qt.ControlModifier
+                ),
+                shift_down=(
+                    (mods & QtCore.Qt.ShiftModifier) == QtCore.Qt.ShiftModifier
+                ),
+                key_code=kcode,
+                event=e,
+            )
 
         elif typ == QtCore.QEvent.WindowStateChange:
             # set the size_state of the window.
             state = obj.windowState()
             if state & QtCore.Qt.WindowMaximized:
-                window.size_state = 'maximized'
+                window.size_state = "maximized"
             else:
-                window.size_state = 'normal'
+                window.size_state = "normal"
 
         return False
