@@ -1,30 +1,25 @@
-#------------------------------------------------------------------------------
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: Enthought, Inc.
-#
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 
 """ Enthought pyface package component
 """
 
-# Major package imports.
+
 import sys
 import wx
 
-# Enthought library imports.
-from traits.api import Bool, Enum, Int, provides, Str, Unicode
 
-# Local imports.
+from traits.api import Bool, Enum, Int, provides, Str
+
+
 from pyface.i_dialog import IDialog, MDialog
 from pyface.constant import OK, CANCEL, YES, NO
 from .window import Window
@@ -32,15 +27,15 @@ from .window import Window
 
 # Map wx dialog related constants to the pyface equivalents.
 _RESULT_MAP = {
-    wx.ID_OK     : OK,
-    wx.ID_CANCEL : CANCEL,
-    wx.ID_YES    : YES,
-    wx.ID_NO     : NO,
-    wx.ID_CLOSE  : CANCEL,
+    wx.ID_OK: OK,
+    wx.ID_CANCEL: CANCEL,
+    wx.ID_YES: YES,
+    wx.ID_NO: NO,
+    wx.ID_CLOSE: CANCEL,
     # There seems to be a bug in wx.SingleChoiceDialog that allows it to return
     # 0 when it is closed via the window (closing it via the buttons works just
     # fine).
-    0            : CANCEL
+    0: CANCEL,
 }
 
 
@@ -50,30 +45,29 @@ class Dialog(MDialog, Window):
     interface for the API documentation.
     """
 
+    # 'IDialog' interface -------------------------------------------------#
 
-    #### 'IDialog' interface ##################################################
+    cancel_label = Str()
 
-    cancel_label = Unicode
+    help_id = Str()
 
-    help_id = Str
+    help_label = Str()
 
-    help_label = Unicode
-
-    ok_label = Unicode
+    ok_label = Str()
 
     resizeable = Bool(True)
 
     return_code = Int(OK)
 
-    style = Enum('modal', 'nonmodal')
+    style = Enum("modal", "nonmodal")
 
-    #### 'IWindow' interface ##################################################
+    # 'IWindow' interface -------------------------------------------------#
 
-    title = Unicode("Dialog")
+    title = Str("Dialog")
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Protected 'IDialog' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _create_buttons(self, parent):
         sizer = wx.StdDialogButtonSizer()
@@ -86,7 +80,7 @@ class Dialog(MDialog, Window):
 
         self._wx_ok = ok = wx.Button(parent, wx.ID_OK, label)
         ok.SetDefault()
-        wx.EVT_BUTTON(parent, wx.ID_OK, self._wx_on_ok)
+        parent.Bind(wx.EVT_BUTTON, self._wx_on_ok, id=wx.ID_OK)
         sizer.AddButton(ok)
 
         # The 'Cancel' button.
@@ -96,7 +90,7 @@ class Dialog(MDialog, Window):
             label = "Cancel"
 
         self._wx_cancel = cancel = wx.Button(parent, wx.ID_CANCEL, label)
-        wx.EVT_BUTTON(parent, wx.ID_CANCEL, self._wx_on_cancel)
+        parent.Bind(wx.EVT_BUTTON, self._wx_on_cancel, id=wx.ID_CANCEL)
         sizer.AddButton(cancel)
 
         # The 'Help' button.
@@ -107,7 +101,7 @@ class Dialog(MDialog, Window):
                 label = "Help"
 
             help = wx.Button(parent, wx.ID_HELP, label)
-            wx.EVT_BUTTON(parent, wx.ID_HELP, self._wx_on_help)
+            parent.Bind(wx.EVT_BUTTON, self._wx_on_help, id=wx.ID_HELP)
             sizer.AddButton(help)
 
         sizer.Realize()
@@ -142,15 +136,15 @@ class Dialog(MDialog, Window):
         return panel
 
     def _show_modal(self):
-        if sys.platform == 'darwin':
+        if sys.platform == "darwin":
             # Calling Show(False) is needed on the Mac for the modal dialog
             # to show up at all.
             self.control.Show(False)
         return _RESULT_MAP[self.control.ShowModal()]
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Protected 'IWidget' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _create_control(self, parent):
         style = wx.DEFAULT_DIALOG_STYLE | wx.CLIP_CHILDREN
@@ -158,10 +152,11 @@ class Dialog(MDialog, Window):
         if self.resizeable:
             style |= wx.RESIZE_BORDER
 
-        return wx.Dialog(parent, -1, self.title, self.position, self.size,
-                         style)
+        return wx.Dialog(
+            parent, -1, self.title, self.position, self.size, style
+        )
 
-    #### wx event handlers ####################################################
+    # wx event handlers ----------------------------------------------------
 
     def _wx_on_ok(self, event):
         """ Called when the 'OK' button is pressed. """
