@@ -1,15 +1,13 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2007, Riverbank Computing Limited
-# All rights reserved.
-#
-# Copyright (c) 2017, Enthought, Inc.
+# (C) Copyright 2007 Riverbank Computing Limited
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-#------------------------------------------------------------------------------
+#
+# Thanks for using Enthought open source!
 
 import wx
 
@@ -39,7 +37,7 @@ wx.Log.SetActiveTarget(_log)
 
 
 # create the toolkit object
-toolkit_object = Toolkit('pyface', 'wx', 'pyface.ui.wx')
+toolkit_object = Toolkit("pyface", "wx", "pyface.ui.wx")
 
 
 # ensure that Traits has a UI handler appropriate for the toolkit.
