@@ -1,32 +1,33 @@
-#------------------------------------------------------------------------------
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2016, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: Enthought Developers
-#
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 
 """ Defines common traits used within the pyface library. """
 import logging
 
-from traits.api import ABCHasStrictTraits, Enum, Range, TraitError, TraitType
+from traits.api import (
+    ABCHasStrictTraits,
+    DefaultValue,
+    Enum,
+    Range,
+    TraitError,
+    TraitType,
+)
 from traits.trait_base import get_resource_path
-import six
 
 
 logger = logging.getLogger(__name__)
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 #  Images
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 image_resource_cache = {}
 image_bitmap_cache = {}
@@ -35,20 +36,21 @@ image_bitmap_cache = {}
 def convert_image(value, level=3):
     """ Converts a specified value to an ImageResource if possible.
     """
-    if not isinstance( value, six.string_types ):
+    if not isinstance(value, str):
         return value
 
     key = value
-    is_pyface_image = value.startswith('@')
+    is_pyface_image = value.startswith("@")
     if not is_pyface_image:
         search_path = get_resource_path(level)
-        key = '%s[%s]' % (value, search_path)
+        key = "%s[%s]" % (value, search_path)
 
     result = image_resource_cache.get(key)
     if result is None:
         if is_pyface_image:
             try:
                 from .image.image import ImageLibrary
+
                 result = ImageLibrary.image_resource(value)
             except Exception as exc:
                 logger.error("Can't load image resource '%s'." % value)
@@ -56,6 +58,7 @@ def convert_image(value, level=3):
                 result = None
         else:
             from pyface.image_resource import ImageResource
+
             result = ImageResource(value, search_path=[search_path])
 
         image_resource_cache[key] = result
@@ -68,8 +71,9 @@ def convert_bitmap(image_resource):
     """
     bitmap = image_bitmap_cache.get(image_resource)
     if (bitmap is None) and (image_resource is not None):
-        image_bitmap_cache[image_resource] = bitmap = \
-            image_resource.create_bitmap()
+        image_bitmap_cache[
+            image_resource
+        ] = bitmap = image_resource.create_bitmap()
 
     return bitmap
 
@@ -83,7 +87,7 @@ class Image(TraitType):
     default_value = None
 
     # A description of the type of value this trait accepts:
-    info_text = 'an ImageResource or string that can be used to define one'
+    info_text = "an ImageResource or string that can be used to define one"
 
     def __init__(self, value=None, **metadata):
         """ Creates an Image trait.
@@ -114,15 +118,16 @@ class Image(TraitType):
         """ Returns the default UI editor for the trait.
         """
         from traitsui.editors.api import ImageEditor
+
         return ImageEditor()
 
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 #  Borders, Margins and Layout
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
+
 
 class BaseMB(ABCHasStrictTraits):
-
     def __init__(self, *args, **traits):
         """ Map posiitonal arguments to traits.
 
@@ -142,10 +147,12 @@ class BaseMB(ABCHasStrictTraits):
             elif n == 4:
                 left, right, top, bottom = args
             else:
-                raise TraitError('0, 1, 2 or 4 arguments expected, but %d '
-                                 'specified' % n)
-            traits.update({'left': left, 'right': right,
-                           'top': top, 'bottom': bottom})
+                raise TraitError(
+                    "0, 1, 2 or 4 arguments expected, but %d " "specified" % n
+                )
+            traits.update(
+                {"left": left, "right": right, "top": top, "bottom": bottom}
+            )
 
         super(BaseMB, self).__init__(**traits)
 
@@ -192,11 +199,13 @@ class HasMargin(TraitType):
     default_value = Margin(0)
 
     # A description of the type of value this trait accepts:
-    info_text = ('a Margin instance, or an integer in the range from -32 to 32 '
-                 'or a tuple with 1, 2 or 4 integers in that range that can be '
-                 'used to define one')
+    info_text = (
+        "a Margin instance, or an integer in the range from -32 to 32 "
+        "or a tuple with 1, 2 or 4 integers in that range that can be "
+        "used to define one"
+    )
 
-    def validate (self, object, name, value):
+    def validate(self, object, name, value):
         """ Validates that a specified value is valid for this trait.
         """
         if isinstance(value, int):
@@ -220,7 +229,7 @@ class HasMargin(TraitType):
                 (default_value_type, default_value)
             which describes the default value for this trait.
         """
-        dv  = self.default_value
+        dv = self.default_value
         dvt = self.default_value_type
         if dvt < 0:
             if isinstance(dv, int):
@@ -231,8 +240,8 @@ class HasMargin(TraitType):
             if not isinstance(dv, self.klass):
                 return super(HasMargin, self).get_default_value()
 
-            self.default_value_type = dvt = 7
-            dv = (self.klass, (), dv.get())
+            self.default_value_type = dvt = DefaultValue.callable_and_args
+            dv = (self.klass, (), dv.trait_get())
 
         return (dvt, dv)
 
@@ -246,16 +255,18 @@ class HasBorder(HasMargin):
     klass = Border
 
     # Define the default value for the trait:
-    default_value = Border()
+    default_value = Border(0)
 
     # A description of the type of value this trait accepts:
-    info_text = ('a Border instance, or an integer in the range from 0 to 32 '
-                 'or a tuple with 1, 2 or 4 integers in that range that can be '
-                 'used to define one')
+    info_text = (
+        "a Border instance, or an integer in the range from 0 to 32 "
+        "or a tuple with 1, 2 or 4 integers in that range that can be "
+        "used to define one"
+    )
 
 
 #: The position of an image relative to its associated text.
-Position = Enum('left', 'right', 'above', 'below')
+Position = Enum("left", "right", "above", "below")
 
 #: The alignment of text within a control.
-Alignment = Enum('default', 'left', 'center', 'right')
+Alignment = Enum("default", "left", "center", "right")
